import { EventData, View, ViewBase, Property, Color, ObservableArray } from '@nativescript/core';
export declare enum CalendarViewMode {
    Week = "Week",
    Month = "Month",
    MonthNames = "MonthNames",
    Year = "Year",
    Day = "Day"
}
export declare enum CalendarSelectionShape {
    Round = "Round",
    Square = "Square",
    None = "None"
}
export declare enum CalendarEventsViewMode {
    None = "None",
    Inline = "Inline",
    Popover = "Popover"
}
export declare enum CalendarSelectionMode {
    None = "None",
    Single = "Single",
    Multiple = "Multiple",
    Range = "Range"
}
export declare enum CalendarTransitionMode {
    None = "None",
    Slide = "Slide",
    Stack = "Stack",
    Flip = "Flip",
    Fold = "Fold",
    Float = "Float",
    Rotate = "Rotate",
    Plain = "Plain",
    Free = "Free",
    Combo = "Combo",
    Overlap = "Overlap"
}
/**
 * Font styles
 */
export declare enum CalendarFontStyle {
    /**
     * Regular font style
     */
    Normal = "Normal",
    /**
     * Bold font style
     */
    Bold = "Bold",
    /**
     * Italic font style
     */
    Italic = "Italic",
    /**
     * Combine Bold and Italic styles
     */
    BoldItalic = "BoldItalic"
}
/**
 * Defines the alignment options for cells in Calendar component.
 */
export declare enum CalendarCellAlignment {
    /**
     The cell content is aligned to left.
     */
    Left = "Left",
    /**
     The cell content is aligned to right.
     */
    Right = "Right",
    /**
     The cell content is aligned to top.
     */
    Top = "Top",
    /**
     The cell content is aligned to bottom.
     */
    Bottom = "Bottom",
    /**
     The cell content is aligned horizontally.
     */
    HorizontalCenter = "HorizontalCenter",
    /**
     The cell content is aligned vertically.
     */
    VerticalCenter = "VerticalCenter",
    /**
     The cell content is center aligned both horizontally and vertically.
     */
    Center = "Center"
}
export declare class DateRange {
    private _startDate;
    private _endDate;
    constructor(startDate?: Date, endDate?: Date);
    get startDate(): Date;
    set startDate(value: Date);
    get endDate(): Date;
    set endDate(value: Date);
    toString(): string;
    normalize(): void;
}
export declare class CalendarEvent {
    constructor(title: string, startDate: Date, endDate: Date, isAllDay?: boolean, eventColor?: Color);
    get android(): any;
    get ios(): any;
    get title(): string;
    set title(value: string);
    get startDate(): Date;
    set startDate(value: Date);
    get endDate(): Date;
    set endDate(value: Date);
    set isAllDay(value: boolean);
    get isAllDay(): boolean;
    set eventColor(value: Color);
    get eventColor(): Color;
    protected _setIsAllDay(value: boolean): void;
    protected _getIsAllDay(): boolean;
    protected _setEndDate(date: Date): void;
    protected _getEndDate(): Date;
    protected _setStartDate(date: Date): void;
    protected _getStartDate(): Date;
    protected _setTitle(value: string): void;
    protected _getTitle(): string;
    protected _setEventColor(value: Color): void;
    protected _getEventColor(): Color;
}
export declare class CalendarViewModeChangedEventData implements EventData {
    /**
     *Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The old value of the ViewMode property.
     */
    oldValue: CalendarViewMode;
    /**
     * The new value of the ViewMode property.
     */
    newValue: CalendarViewMode;
}
export declare class CalendarCellTapEventData implements EventData {
    /**
     * Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The related native cell.
     */
    cell: any;
    /**
     * The related Date.
     */
    date: Date;
}
export declare class CalendarSelectionEventData implements EventData {
    /**
     * Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The relative Date.
     */
    date: Date;
}
export declare class CalendarInlineEventSelectedData implements EventData {
    /**
     * Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The data for inline event selected in calendar.
     */
    eventData: CalendarEvent;
}
export declare class CalendarDayViewEventSelectedData implements EventData {
    /**
     * Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The data for day view event selected in calendar.
     */
    eventData: CalendarEvent;
}
export declare class CalendarNavigationEventData implements EventData {
    /**
     * Returns the name of the event that has been fired.
     */
    eventName: string;
    /**
     * The object that fires the event.
     */
    object: any;
    /**
     * The relative Date.
     */
    date: Date;
}
export declare class CalendarMonthViewStyle extends ViewBase {
    owner: RadCalendar;
    showWeekNumbers: boolean;
    showTitle: boolean;
    showDayNames: boolean;
    todayCellStyle: DayCellStyle;
    disabledCellStyle: DayCellStyle;
    anotherMonthCellStyle: DayCellStyle;
    backgroundColor: Color;
    dayCellStyle: DayCellStyle;
    dayNameCellStyle: CellStyle;
    weekNumberCellStyle: CellStyle;
    weekendCellStyle: CellStyle;
    titleCellStyle: CellStyle;
    selectedDayCellStyle: DayCellStyle;
    inlineEventCellStyle: InlineEventCellStyle;
    selectionShape: CalendarSelectionShape;
    selectionShapeSize: number;
    selectionShapeColor: Color;
    updateViewStyles(forceUpdate?: boolean): void;
    static showWeekNumbersProperty: Property<CalendarMonthViewStyle, boolean>;
    static selectionShapeProperty: Property<CalendarMonthViewStyle, CalendarSelectionShape>;
    private onSelectionShapePropertyChanged;
    protected onSelectionShapeChanged(oldValue: CalendarSelectionShape, newValue: CalendarSelectionShape): void;
    static selectionShapeSizeProperty: Property<CalendarMonthViewStyle, number>;
    private onSelectionShapeSizePropertyChanged;
    protected onSelectionShapeSizeChanged(oldValue: number, newValue: number): void;
    static selectionShapeColorProperty: Property<CalendarMonthViewStyle, Color>;
    private onSelectionShapeColorPropertyChanged;
    protected onSelectionShapeColorChanged(oldValue: Color, newValue: Color): void;
    private onShowWeekNumbersPropertyChanged;
    protected onShowWeekNumbersChanged(oldValue: boolean, newValue: boolean): void;
    static showTitleProperty: Property<CalendarMonthViewStyle, boolean>;
    private onShowTitlePropertyChanged;
    protected onShowTitleChanged(oldValue: boolean, newValue: boolean): void;
    static showDayNamesProperty: Property<CalendarMonthViewStyle, boolean>;
    private onShowDayNamesPropertyChanged;
    protected onShowDayNamesChanged(oldValue: boolean, newValue: boolean): void;
    static backgroundColorProperty: Property<CalendarMonthViewStyle, Color>;
    private onCellBackgroundColorPropertyChanged;
    protected onBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static dayCellStyleProperty: Property<CalendarMonthViewStyle, DayCellStyle>;
    private onDayCellStylePropertyChanged;
    protected onDayCellStyleChanged(oldValue: DayCellStyle, newValue: DayCellStyle): void;
    static selectedDayCellStyleProperty: Property<CalendarMonthViewStyle, DayCellStyle>;
    private onSelectedDayCellStylePropertyChanged;
    protected onSelectedDayCellStyleChanged(oldValue: DayCellStyle, newValue: DayCellStyle): void;
    static todayCellStyleProperty: Property<CalendarMonthViewStyle, DayCellStyle>;
    private onTodayCellStylePropertyChanged;
    protected onTodayCellStyleChanged(oldValue: DayCellStyle, newValue: DayCellStyle): void;
    static disabledCellStyleProperty: Property<CalendarMonthViewStyle, DayCellStyle>;
    private onDisabledCellStylePropertyChanged;
    protected onDisabledCellStyleChanged(oldValue: DayCellStyle, newValue: DayCellStyle): void;
    static anotherMonthCellStyleProperty: Property<CalendarMonthViewStyle, DayCellStyle>;
    private onAnotherMonthCellStylePropertyChanged;
    protected onAnotherMonthCellStyleChanged(oldValue: DayCellStyle, newValue: DayCellStyle): void;
    static dayNameCellStyleProperty: Property<CalendarMonthViewStyle, CellStyle>;
    private onDayNameCellStylePropertyChanged;
    protected onDayNameCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static weekNumberCellStyleProperty: Property<CalendarMonthViewStyle, CellStyle>;
    private onWeekNumberCellStylePropertyChanged;
    protected onWeekNumberCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static weekendCellStyleProperty: Property<CalendarMonthViewStyle, CellStyle>;
    private onWeekendCellStylePropertyChanged;
    protected onWeekendCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static titleCellStyleProperty: Property<CalendarMonthViewStyle, CellStyle>;
    private onTitleCellStylePropertyChanged;
    protected onTitleCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static inlineEventCellStyleProperty: Property<CalendarMonthViewStyle, InlineEventCellStyle>;
    private onInlineEventCellStylePropertyChanged;
    protected onInlineEventCellStyleChanged(oldValue: InlineEventCellStyle, newValue: InlineEventCellStyle): void;
}
/**
 * Style class for Week view mode
 */
export declare class CalendarWeekViewStyle extends CalendarMonthViewStyle {
}
/**
 * Style class for Day view mode
 */
export declare class CalendarDayViewStyle extends CalendarWeekViewStyle {
    showWeek: boolean;
    dayEventsViewStyle: DayEventsViewStyle;
    allDayEventsViewStyle: AllDayEventsViewStyle;
    static showWeekProperty: Property<CalendarDayViewStyle, boolean>;
    private onShowWeekPropertyChanged;
    protected onShowWeekChanged(oldValue: boolean, newValue: boolean): void;
    static dayEventsViewStyleProperty: Property<CalendarDayViewStyle, DayEventsViewStyle>;
    private onDayEventsViewStylePropertyChanged;
    protected onDayEventsViewStyleChanged(oldValue: DayEventsViewStyle, newValue: DayEventsViewStyle): void;
    static allDayEventsViewStyleProperty: Property<CalendarDayViewStyle, AllDayEventsViewStyle>;
    private onAllDayEventsViewStylePropertyChanged;
    protected onAllDayEventsViewStyleChanged(oldValue: AllDayEventsViewStyle, newValue: AllDayEventsViewStyle): void;
}
/**
 * Style class for Year view mode
 */
export declare class CalendarYearViewStyle extends ViewBase {
    owner: RadCalendar;
    titleCellStyle: CellStyle;
    monthCellStyle: MonthCellStyle;
    static titleCellStyleProperty: Property<CalendarYearViewStyle, CellStyle>;
    private onTitleCellStylePropertyChanged;
    protected onTitleCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static monthCellStyleProperty: Property<CalendarYearViewStyle, MonthCellStyle>;
    private onMonthCellStylePropertyChanged;
    protected onMonthCellStyleChanged(oldValue: MonthCellStyle, newValue: MonthCellStyle): void;
}
/**
 * Style class for year view with month names only view mode
 */
export declare class CalendarMonthNamesViewStyle extends ViewBase {
    owner: RadCalendar;
    titleCellStyle: CellStyle;
    monthNameCellStyle: CellStyle;
    static titleCellStyleProperty: Property<CalendarMonthNamesViewStyle, CellStyle>;
    private onTitleCellStylePropertyChanged;
    protected onTitleCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
    static monthNameCellStyleProperty: Property<CalendarMonthNamesViewStyle, CellStyle>;
    private onMonthNameCellStylePropertyChanged;
    protected onMonthNameCellStyleChanged(oldValue: CellStyle, newValue: CellStyle): void;
}
/**
 * The style class with customization properties for months in year view
 * Note: this class is not inherited from CellStyle
 */
export declare class MonthCellStyle extends ViewBase {
    owner: any;
    weekendTextColor: Color;
    todayTextColor: Color;
    dayTextColor: Color;
    dayFontName: string;
    dayFontStyle: CalendarFontStyle;
    dayTextSize: number;
    dayNameTextColor: Color;
    dayNameFontName: string;
    dayNameFontStyle: CalendarFontStyle;
    dayNameTextSize: number;
    monthNameTextColor: Color;
    monthNameFontName: string;
    monthNameFontStyle: CalendarFontStyle;
    monthNameTextSize: number;
    static weekendTextColorProperty: Property<MonthCellStyle, Color>;
    private onWeekendТextColorPropertyChanged;
    protected onWeekendTextColorChanged(oldValue: Color, newValue: Color): void;
    static todayTextColorProperty: Property<MonthCellStyle, Color>;
    private onTodayТextColorPropertyChanged;
    protected onTodayTextColorChanged(oldValue: Color, newValue: Color): void;
    static dayTextColorProperty: Property<MonthCellStyle, Color>;
    private onDayТextColorPropertyChanged;
    protected onDayTextColorChanged(oldValue: Color, newValue: Color): void;
    static dayFontNameProperty: Property<MonthCellStyle, string>;
    private onDayFontNamePropertyChanged;
    protected onDayFontNameChanged(oldValue: string, newValue: string): void;
    static dayFontStyleProperty: Property<MonthCellStyle, CalendarFontStyle>;
    private onDayFontStylePropertyChanged;
    protected onDayFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static dayTextSizeProperty: Property<MonthCellStyle, number>;
    private onDayTextSizePropertyChanged;
    protected onDayTextSizeChanged(oldValue: number, newValue: number): void;
    static dayNameTextColorProperty: Property<MonthCellStyle, Color>;
    private onDayNameТextColorPropertyChanged;
    protected onDayNameTextColorChanged(oldValue: Color, newValue: Color): void;
    static dayNameFontNameProperty: Property<MonthCellStyle, string>;
    private onDayNameFontNamePropertyChanged;
    protected onDayNameFontNameChanged(oldValue: string, newValue: string): void;
    static dayNameFontStyleProperty: Property<MonthCellStyle, CalendarFontStyle>;
    private onDayNameFontStylePropertyChanged;
    protected onDayNameFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static dayNameTextSizeProperty: Property<MonthCellStyle, number>;
    private onDayNameTextSizePropertyChanged;
    protected onDayNameTextSizeChanged(oldValue: number, newValue: number): void;
    static monthNameTextColorProperty: Property<MonthCellStyle, Color>;
    private onMonthNameТextColorPropertyChanged;
    protected onMonthNameTextColorChanged(oldValue: Color, newValue: Color): void;
    static monthNameFontNameProperty: Property<MonthCellStyle, string>;
    private onMonthNameFontNamePropertyChanged;
    protected onMonthNameFontNameChanged(oldValue: string, newValue: string): void;
    static monthNameFontStyleProperty: Property<MonthCellStyle, CalendarFontStyle>;
    private onMonthNameFontStylePropertyChanged;
    protected onMonthNameFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static monthNameTextSizeProperty: Property<MonthCellStyle, number>;
    private onMonthNameTextSizePropertyChanged;
    protected onMonthNameTextSizeChanged(oldValue: number, newValue: number): void;
}
export declare class CellStyle extends ViewBase {
    owner: any;
    cellBorderWidth: number;
    cellBorderColor: Color;
    cellBackgroundColor: Color;
    cellAlignment: any;
    cellTextColor: Color;
    cellTextFontName: string;
    cellTextFontStyle: CalendarFontStyle;
    cellTextSize: number;
    cellPaddingHorizontal: number;
    cellPaddingVertical: number;
    get ios(): any;
    get android(): any;
    static cellBorderWidthProperty: Property<CellStyle, number>;
    private onCellBorderWidthPropertyChanged;
    protected onCellBorderWidthChanged(oldValue: number, newValue: number): void;
    static cellBorderColorProperty: Property<CellStyle, Color>;
    private onCellBorderColorPropertyChanged;
    protected onCellBorderColorChanged(oldValue: Color, newValue: Color): void;
    static cellBackgroundColorProperty: Property<CellStyle, Color>;
    private onCellBackgroundColorPropertyChanged;
    protected onCellBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static cellAlignmentProperty: Property<CellStyle, any>;
    private onCellAlignmentPropertyChanged;
    protected onCellAlignmentChanged(oldValue: any, newValue: any): void;
    static cellTextColorProperty: Property<CellStyle, Color>;
    private onCellТextColorPropertyChanged;
    protected onCellTextColorChanged(oldValue: Color, newValue: Color): void;
    static cellTextFontNameProperty: Property<CellStyle, string>;
    private onCellTextFontNamePropertyChanged;
    protected onCellTextFontNameChanged(oldValue: string, newValue: string): void;
    static cellTextFontStyleProperty: Property<CellStyle, CalendarFontStyle>;
    private onCellTextFontStylePropertyChanged;
    protected onCellTextFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static cellTextSizeProperty: Property<CellStyle, number>;
    private onCellTextSizePropertyChanged;
    protected onCellTextSizeChanged(oldValue: number, newValue: number): void;
    static cellPaddingHorizontalProperty: Property<CellStyle, number>;
    private onCellPaddingHorizontalPropertyChanged;
    protected onCellPaddingHorizontalChanged(oldValue: number, newValue: number): void;
    static cellPaddingVerticalProperty: Property<CellStyle, number>;
    private onCellPaddingVerticalPropertyChanged;
    protected onCellPaddingVerticalChanged(oldValue: number, newValue: number): void;
}
export declare class DayEventsViewStyle extends ViewBase {
    owner: any;
    backgroundColor: Color;
    timeLabelFormat: string;
    timeLabelTextColor: Color;
    timeLabelTextSize: number;
    timeLinesWidth: number;
    timeLinesColor: Color;
    get ios(): any;
    get android(): any;
    static backgroundColorProperty: Property<DayEventsViewStyle, Color>;
    private onBackgroundColorPropertyChanged;
    protected onBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static timeLabelFormatProperty: Property<DayEventsViewStyle, string>;
    private onTimeLabelFormatPropertyChanged;
    protected onTimeLabelFormatChanged(oldValue: string, newValue: string): void;
    static timeLabelTextColorProperty: Property<DayEventsViewStyle, Color>;
    private onTimeLabelTextColorPropertyChanged;
    protected onTimeLabelTextColorChanged(oldValue: Color, newValue: Color): void;
    static timeLabelFontNameProperty: Property<DayEventsViewStyle, string>;
    private onTimeLabelFontNamePropertyChanged;
    protected onTimeLabelFontNameChanged(oldValue: string, newValue: string): void;
    static timeLabelFontStyleProperty: Property<DayEventsViewStyle, CalendarFontStyle>;
    private onTimeLabelFontStylePropertyChanged;
    protected onTimeLabelFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static timeLabelTextSizeProperty: Property<DayEventsViewStyle, number>;
    private onTimeLabelTextSizePropertyChanged;
    protected onTimeLabelTextSizeChanged(oldValue: number, newValue: number): void;
    static timeLinesWidthProperty: Property<DayEventsViewStyle, number>;
    private onTimeLinesWidthPropertyChanged;
    protected onTimeLinesWidthChanged(oldValue: number, newValue: number): void;
    static timeLinesColorProperty: Property<DayEventsViewStyle, Color>;
    private onTimeLinesColorPropertyChanged;
    protected onTimeLinesColorChanged(oldValue: Color, newValue: Color): void;
}
export declare class AllDayEventsViewStyle extends ViewBase {
    owner: any;
    backgroundColor: Color;
    allDayText: string;
    allDayTextIsVisible: boolean;
    static ALL_DAY_TEXT: string;
    get ios(): any;
    get android(): any;
    static backgroundColorProperty: Property<AllDayEventsViewStyle, Color>;
    private onBackgroundColorPropertyChanged;
    protected onBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static allDayTextProperty: Property<AllDayEventsViewStyle, string>;
    private onAllDayTextPropertyChanged;
    protected onAllDayTextChanged(oldValue: string, newValue: string): void;
    static allDayTextIsVisibleProperty: Property<AllDayEventsViewStyle, boolean>;
    private onAllDayTextIsVisiblePropertyChanged;
    protected onAlDayTextIsVisibleChanged(oldValue: boolean, newValue: boolean): void;
}
export declare class DayCellStyle extends CellStyle {
    showEventsText: boolean;
    eventTextColor: Color;
    eventFontName: string;
    eventFontStyle: CalendarFontStyle;
    eventTextSize: number;
    static showEventsTextProperty: Property<DayCellStyle, boolean>;
    private onShowEventsTextPropertyChanged;
    protected onShowEventsTextChanged(oldValue: boolean, newValue: boolean): void;
    static eventTextColorProperty: Property<DayCellStyle, Color>;
    private onEventTextColorPropertyChanged;
    protected onEventTextColorChanged(oldValue: Color, newValue: Color): void;
    static eventFontNameProperty: Property<DayCellStyle, string>;
    private onEventFontNamePropertyChanged;
    protected onEventFontNameChanged(oldValue: string, newValue: string): void;
    static eventFontStyleProperty: Property<DayCellStyle, CalendarFontStyle>;
    private onEventFontStylePropertyChanged;
    protected onEventFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static eventTextSizeProperty: Property<DayCellStyle, number>;
    private onEventTextSizePropertyChanged;
    protected onEventTextSizeChanged(oldValue: number, newValue: number): void;
}
/**
 * Cell style class for inline events cells in month view
 */
export declare class InlineEventCellStyle extends ViewBase {
    cellBackgroundColor: Color;
    eventTextColor: Color;
    eventFontName: string;
    eventFontStyle: CalendarFontStyle;
    eventTextSize: number;
    timeTextColor: Color;
    timeFontName: string;
    timeFontStyle: CalendarFontStyle;
    timeTextSize: number;
    static cellBackgroundColorProperty: Property<InlineEventCellStyle, Color>;
    private onCellBackgroundColorPropertyChanged;
    protected onCellBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static eventTextColorProperty: Property<InlineEventCellStyle, Color>;
    private onEventTextColorPropertyChanged;
    protected onEventTextColorChanged(oldValue: Color, newValue: Color): void;
    static eventFontNameProperty: Property<InlineEventCellStyle, string>;
    private onEventFontNamePropertyChanged;
    protected onEventFontNameChanged(oldValue: string, newValue: string): void;
    static eventFontStyleProperty: Property<InlineEventCellStyle, CalendarFontStyle>;
    private onEventFontStylePropertyChanged;
    protected onEventFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static eventTextSizeProperty: Property<InlineEventCellStyle, number>;
    private onEventTextSizePropertyChanged;
    protected onEventTextSizeChanged(oldValue: number, newValue: number): void;
    static timeTextColorProperty: Property<InlineEventCellStyle, Color>;
    private onTimeTextColorPropertyChanged;
    protected onTimeTextColorChanged(oldValue: Color, newValue: Color): void;
    static timeFontNameProperty: Property<InlineEventCellStyle, string>;
    private onTimeFontNamePropertyChanged;
    protected onTimeFontNameChanged(oldValue: string, newValue: string): void;
    static timeFontStyleProperty: Property<InlineEventCellStyle, CalendarFontStyle>;
    private onTimeFontStylePropertyChanged;
    protected onTimeFontStyleChanged(oldValue: CalendarFontStyle, newValue: CalendarFontStyle): void;
    static timeTextSizeProperty: Property<InlineEventCellStyle, number>;
    private onTimeTextSizePropertyChanged;
    protected onTimeTextSizeChanged(oldValue: number, newValue: number): void;
}
export declare class RadCalendar extends View {
    static dateSelectedEvent: string;
    static dateDeselectedEvent: string;
    static cellTapEvent: string;
    static inlineEventSelectedEvent: string;
    static dayViewEventSelectedEvent: string;
    static navigatedToDateEvent: string;
    static navigatingToDateStartedEvent: string;
    static viewModeChangedEvent: string;
    locale: string;
    minDate: Date;
    maxDate: Date;
    selectedDate: Date;
    selectedDates: any;
    selectedDateRange: DateRange;
    viewMode: CalendarViewMode;
    eventsViewMode: CalendarEventsViewMode;
    selectionMode: CalendarSelectionMode;
    transitionMode: CalendarTransitionMode;
    displayedDate: Date;
    eventSource: ObservableArray<CalendarEvent>;
    horizontalTransition: boolean;
    dayViewStyle: CalendarDayViewStyle;
    monthViewStyle: CalendarMonthViewStyle;
    weekViewStyle: CalendarWeekViewStyle;
    yearViewStyle: CalendarYearViewStyle;
    monthNamesViewStyle: CalendarMonthNamesViewStyle;
    private _silentSelectionUpdate;
    static localeProperty: Property<RadCalendar, string>;
    protected onLocalePropertyChanged(oldValue: string, newValue: string): void;
    static minDateProperty: Property<RadCalendar, Date>;
    private onMinDatePropertyChanged;
    static maxDateProperty: Property<RadCalendar, Date>;
    private onMaxDatePropertyChanged;
    static selectedDateProperty: Property<RadCalendar, Date>;
    private onSelectedDatePropertyChanged;
    static selectedDatesProperty: Property<RadCalendar, any>;
    private onSelectedDatesPropertyChanged;
    static selectedDateRangeProperty: Property<RadCalendar, DateRange>;
    private onSelectedDateRangePropertyChanged;
    static viewModeProperty: Property<RadCalendar, CalendarViewMode>;
    private onViewModePropertyChanged;
    static eventsViewModeProperty: Property<RadCalendar, CalendarEventsViewMode>;
    private onEventsViewModePropertyChanged;
    static selectionModeProperty: Property<RadCalendar, CalendarSelectionMode>;
    private onSelectionModePropertyChanged;
    static transitionModeProperty: Property<RadCalendar, CalendarTransitionMode>;
    private onTransitionModePropertyChanged;
    static displayedDateProperty: Property<RadCalendar, Date>;
    private onDisplayedDatePropertyChanged;
    static eventSourceProperty: Property<RadCalendar, ObservableArray<CalendarEvent>>;
    private onEventSourcePropertyChanged;
    static horizontalTransitionProperty: Property<RadCalendar, boolean>;
    private onHorizontalTransitionPropertyChanged;
    static monthViewStyleProperty: Property<RadCalendar, CalendarMonthViewStyle>;
    private onMonthViewStylePropertyChanged;
    static weekViewStyleProperty: Property<RadCalendar, CalendarWeekViewStyle>;
    private onWeekViewStylePropertyChanged;
    static dayViewStyleProperty: Property<RadCalendar, CalendarDayViewStyle>;
    private onDayViewStylePropertyChanged;
    static yearViewStyleProperty: Property<RadCalendar, CalendarYearViewStyle>;
    private onYearViewStylePropertyChanged;
    static monthNamesViewStyleProperty: Property<RadCalendar, CalendarMonthNamesViewStyle>;
    private onMonthNamesViewStylePropertyChanged;
    reload(): void;
    navigateForward(): void;
    navigateBack(): void;
    goToDate(date: Date): void;
    getEventsForDate(date: Date): Array<CalendarEvent>;
    private getSelectedDatesList;
    _addSelectedDate(date: Date): void;
    _removeSelectedDate(date: Date): void;
    clearSelection(): void;
    protected onEventSourceChanged(oldValue: ObservableArray<CalendarEvent>, newValue: ObservableArray<CalendarEvent>): void;
    protected EventSourceChangedInternal(data: any): void;
    private getSelectionWarningInfo;
    updateEventSource(): void;
    static areDatesSame(date1: Date, date2: Date): boolean;
    protected onDisplayedDateChanged(oldValue: Date, newValue: Date): void;
    protected onSelectionModeChanged(oldValue: CalendarSelectionMode, newValue: CalendarSelectionMode): void;
    protected onTransitionModeChanged(oldValue: CalendarTransitionMode, newValue: CalendarTransitionMode): void;
    protected onViewModeChanged(oldValue: CalendarViewMode, newValue: CalendarViewMode): void;
    protected onEventsViewModeChanged(oldValue: CalendarEventsViewMode, newValue: CalendarEventsViewMode): void;
    protected onSelectedDateRangeChanged(oldValue: DateRange, newValue: DateRange): void;
    protected onSelectedDatesChanged(oldValue: any, newValue: any): void;
    protected onSelectedDateChanged(oldValue: Date, newValue: Date): void;
    protected onMaxDateChanged(oldValue: Date, newValue: Date): void;
    protected onMinDateChanged(oldValue: Date, newValue: Date): void;
    protected onHorizontalTransitionChanged(oldValue: boolean, newValue: boolean): void;
    protected onMonthViewStyleChanged(oldValue: CalendarMonthViewStyle, newValue: CalendarMonthViewStyle): void;
    protected onWeekViewStyleChanged(oldValue: CalendarWeekViewStyle, newValue: CalendarWeekViewStyle): void;
    protected onDayViewStyleChanged(oldValue: CalendarDayViewStyle, newValue: CalendarDayViewStyle): void;
    protected onYearViewStyleChanged(oldValue: CalendarYearViewStyle, newValue: CalendarYearViewStyle): void;
    protected onMonthNamesViewStyleChanged(oldValue: CalendarMonthNamesViewStyle, newValue: CalendarMonthNamesViewStyle): void;
}
